MinRotateAnimation class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MinRotateAnimation
- Available extensions
Constructors
- MinRotateAnimation({Key? key, required Widget child, Duration duration = const Duration(milliseconds: 300), double begin = 0.0, double end = 1.0, Curve curve = Curves.easeInOut, bool reverse = false, bool isRepeat = false, Alignment alignment = Alignment.center, Offset origin = Offset.zero, void listener(AnimationController)?, void onEnd()?})
-
const
Properties
- alignment → Alignment
-
final
- begin → double
-
final
- child → Widget
-
final
- curve → Curve
-
final
- duration → Duration
-
final
- end → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRepeat → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- listener → void Function(AnimationController)?
-
final
- onEnd → void Function()?
-
final
- origin → Offset
-
final
- reverse → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
fadeAnimation(
{Key? key, required Duration duration, double begin = 0.0, double end = 1.0, Curve curve = Curves.linear, bool reverse = false, bool isRepeat = false, dynamic listener(AnimationController)?, dynamic onEnd()?}) → Widget -
Available on Widget, provided by the ExtensionAnimations extension
-
flipAnimation(
{Key? key, required Duration duration, double begin = 0.0, double end = 3.14159, Curve curve = Curves.linear, bool reverse = false, bool isRepeat = false, dynamic listener(AnimationController)?, dynamic onEnd()?, Matrix4? transform}) → Widget -
Available on Widget, provided by the ExtensionAnimations extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rotateAnimation(
{Key? key, required Duration duration, double begin = 0.0, double end = 1.0, Curve curve = Curves.linear, bool reverse = false, bool isRepeat = false, Alignment alignment = Alignment.center, Offset origin = Offset.zero, dynamic listener(AnimationController)?, dynamic onEnd()?}) → Widget -
Available on Widget, provided by the ExtensionAnimations extension
-
scaleAnimation(
{Key? key, required Duration duration, double begin = 0.0, double end = 1.0, Curve curve = Curves.linear, bool reverse = false, Alignment alignment = Alignment.center, bool isRepeat = false, dynamic listener(AnimationController)?, dynamic onEnd()?}) → Widget -
Available on Widget, provided by the ExtensionAnimations extension
-
sizeAnimation(
{Key? key, required Duration duration, double begin = 0.0, double end = 1.0, Curve curve = Curves.linear, bool reverse = false, bool isRepeat = false, Axis axis = Axis.vertical, dynamic listener(AnimationController)?, dynamic onEnd()?}) → Widget -
Available on Widget, provided by the ExtensionAnimations extension
-
slideAnimation(
{Key? key, required Duration duration, double x = 10.0, double y = 10.0, Curve curve = Curves.linear, bool reverse = false, bool isRepeat = false, dynamic listener(AnimationController)?, dynamic onEnd()?}) → Widget -
Available on Widget, provided by the ExtensionAnimations extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited